<?php

namespace Drupal\crowdsec\Commands;

use CrowdSec\CapiClient\ClientException;
use Drupal\crowdsec\Client;
use Drupal\crowdsec\Form\Settings;
use Drush\Commands\DrushCommands;
use Psr\Cache\CacheException;
use Psr\Cache\InvalidArgumentException;

/**
 * A Drush commandfile.
 */
class CrowdSec extends DrushCommands {

  /**
   * The CrowdSec client service.
   *
   * @var \Drupal\crowdsec\Client
   */
  protected Client $client;

  /**
   * Constructs the CrowdSec event subscriber service.
   *
   * @param \Drupal\crowdsec\Client $client
   *   The CrowdSec client service.
   */
  public function __construct(Client $client) {
    $this->client = $client;
    parent::__construct();
  }

  /**
   * Collect data from CrowdSec.
   *
   * @usage crowdsec:collect
   *   Collect data from CrowdSec.
   *
   * @command crowdsec:collect
   */
  public function collect(): void {
    $remediation = $this->client->remediation();
    try {
      $remediation->refreshDecisions();
    }
    catch (InvalidArgumentException | CacheException $e) {
      $this->logger->critical($e->getMessage());
    }
  }

  /**
   * Test CrowdSec by sending a signal to ban an IP address.
   *
   * @usage crowdsec:test:ban 1.2.3.4
   *   Test CrowdSec by sending a signal to ban the IP 1.2.3.4.
   *
   * @command crowdsec:test:ban
   */
  public function testBanIp(string $ip): void {
    $watcher = $this->client->watcher();
    try {
      $signal = $watcher->createSignal(Settings::SCENARIO_FLOOD, $ip, NULL, NULL);
      $watcher->pushSignals([$signal]);
    }
    catch (ClientException $e) {
      $this->logger->critical($e->getMessage());
    }
  }

}
